<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../src/mainwindow.ui" line="14"/>
        <source>OpenSSH Authentication Passphrase request</source>
        <translation>Abfrage der OpenSSH-Authentisierungs-Passphrase</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="20"/>
        <source>Enter your SSH passphrase for request:</source>
        <translation>SSH-Passphrase eingeben:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/main.cpp" line="52"/>
        <source>unknown request</source>
        <translation>Unbekannte Abfrage</translation>
    </message>
</context>
</TS>
